@@ -27,30 +27,55 @@
 #define __AppKitDefines_INCLUDE
 #import <GNUstepBase/GSVersionMacros.h>
 
+#ifdef __cplusplus
+#define APPKIT_EXTERN extern "C"
+#else
+#define APPKIT_EXTERN extern
+#endif
+
 #ifdef GNUSTEP_WITH_DLL 
 
 #if BUILD_libgnustep_gui_DLL
-#
-# if defined(__MINGW32__)
+
+# if defined(__MINGW__)
   /* On Mingw, the compiler will export all symbols automatically, so
    * __declspec(dllexport) is not needed.
    */
-#  define APPKIT_EXPORT  extern
-#  define APPKIT_DECLARE 
+#  define APPKIT_EXPORT_CLASS
+#  define APPKIT_EXPORT  APPKIT_EXTERN
+#  define APPKIT_IMPORT  __declspec(dllimport)
+#  define APPKIT_DECLARE
 # else
-#  define APPKIT_EXPORT  __declspec(dllexport)
+#  define APPKIT_EXPORT_CLASS  __declspec(dllexport)
+#  define APPKIT_EXPORT  APPKIT_EXTERN __declspec(dllexport)
+#  define APPKIT_IMPORT  __declspec(dllimport)
 #  define APPKIT_DECLARE __declspec(dllexport)
 # endif
 #else
-#  define APPKIT_EXPORT  extern __declspec(dllimport)
+# if defined(__MINGW__)
+   /* MinGW does not need dllimport on ObjC classes and produces warnings. */
+#  define APPKIT_EXPORT_CLASS
+# else
+#  define APPKIT_EXPORT_CLASS  __declspec(dllimport)
+# endif
+#  define APPKIT_IMPORT  __declspec(dllimport)
+#  define APPKIT_EXPORT  APPKIT_EXTERN __declspec(dllimport)
 #  define APPKIT_DECLARE __declspec(dllimport)
 #endif
 
 #else /* GNUSTEP_WITH[OUT]_DLL */
 
-#  define APPKIT_EXPORT extern
+#  define APPKIT_EXPORT_CLASS
+#  define APPKIT_EXPORT APPKIT_EXTERN
+#  define APPKIT_IMPORT
 #  define APPKIT_DECLARE
 
 #endif
 
+#if defined(__clang__) && !defined(__MINGW32__)
+#  define PACKAGE_SCOPE @package
+#else
+#  define PACKAGE_SCOPE @public
+#endif
+
 #endif /* __AppKitDefines_INCLUDE */
