@@ -167,11 +167,16 @@ enum {
   NSCellHitTrackableArea = 4
 };
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+typedef NSUInteger NSCellHitResult;
+#endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
 enum {
   NSBackgroundStyleLight = 0,
+  NSBackgroundStyleNormal = 0,
   NSBackgroundStyleDark = 1,
+  NSBackgroundStyleEmphasized = 1,
   NSBackgroundStyleRaised = 2,
   NSBackgroundStyleLowered = 3
 };
@@ -490,10 +495,17 @@ APPKIT_EXPORT_CLASS
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
 - (NSBackgroundStyle)backgroundStyle;
 - (void)setBackgroundStyle:(NSBackgroundStyle)backgroundStyle;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+- (NSCellHitResult)hitTestForEvent:(NSEvent *)event
+                       inRect:(NSRect)cellFrame
+                       ofView:(NSView *)controlView;
+#else
 - (NSUInteger)hitTestForEvent:(NSEvent *)event
                        inRect:(NSRect)cellFrame
                        ofView:(NSView *)controlView;
 #endif
+#endif
 
 //
 // Managing the Cursor 
