@@ -29,7 +29,7 @@
 
 #ifndef _GNUstep_H_NSClipView
 #define _GNUstep_H_NSClipView
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSView.h>
 
@@ -37,6 +37,7 @@
 @class NSCursor;
 @class NSColor;
 
+APPKIT_EXPORT_CLASS
 @interface NSClipView : NSView
 {
   NSView* _documentView;
@@ -79,21 +80,6 @@
 - (BOOL)drawsBackground;
 #endif
 
-/* Overridden NSView methods */
-- (BOOL)acceptsFirstResponder;
-- (BOOL)isFlipped;
-- (void)rotateByAngle:(float)angle;
-- (void)scaleUnitSquareToSize:(NSSize)newUnitSize;
-- (void)setBoundsOrigin:(NSPoint)aPoint;
-- (void)setBoundsRotation:(float)angle;
-- (void)setBoundsSize:(NSSize)aSize;
-- (void)setFrameSize:(NSSize)aSize;
-- (void)setFrameOrigin:(NSPoint)aPoint;
-- (void)setFrameRotation:(float)angle;
-- (void)translateOriginToPoint:(NSPoint)aPoint;
-- (void)viewBoundsChanged:(NSNotification*)aNotification;
-- (void)viewFrameChanged:(NSNotification*)aNotification;
-
 @end
 
 #endif /* _GNUstep_H_NSClipView */
