@@ -1,4 +1,4 @@
-/* 
+/*
    NSColor.h
 
    The colorful color class
@@ -7,7 +7,7 @@
 
    Author:  Scott Christley <scottc@net-community.com>
    Date: 1996
-   
+
    This file is part of the GNUstep GUI Library.
 
    This library is free software; you can redistribute it and/or
@@ -22,14 +22,14 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; see the file COPYING.LIB.
-   If not, see <http://www.gnu.org/licenses/> or write to the 
-   Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+   If not, see <http://www.gnu.org/licenses/> or write to the
+   Free Software Foundation, 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
-*/ 
+*/
 
 #ifndef _GNUstep_H_NSColor
 #define _GNUstep_H_NSColor
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSCoder.h>
 #import <Foundation/NSObject.h>
@@ -41,29 +41,52 @@
 @class NSImage;
 @class NSColorSpace;
 
-typedef enum _NSControlTint {
+enum _NSControlTint {
     NSDefaultControlTint,
     NSBlueControlTint,
     NSGraphiteControlTint = 6,
     NSClearControlTint
-} NSControlTint;
+};
+typedef NSUInteger NSControlTint;
 
-typedef enum _NSControlSize {
+enum _NSControlSize {
     NSRegularControlSize,
     NSSmallControlSize,
     NSMiniControlSize
-} NSControlSize;
+};
+typedef NSUInteger NSControlSize;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_14, GS_API_LATEST)
+enum _NSColorType {
+    NSColorTypeComponentBased,
+    NSColorTypePattern,
+    NSColorTypeCatalog
+};
+typedef NSInteger NSColorType;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_14, GS_API_LATEST)
+enum _NSColorSystemEffect {
+    NSColorSystemEffectNone,
+    NSColorSystemEffectPressed,
+    NSColorSystemEffectDeepPressed,
+    NSColorSystemEffectDisabled,
+    NSColorSystemEffectRollover
+};
+typedef NSInteger NSColorSystemEffect;
+#endif
 
 /*
  * NSColor is an abstract super class of the class cluster of the real colour classes.
- * For each colour space exists a specific subclass that implements the behaviour for 
+ * For each colour space exists a specific subclass that implements the behaviour for
  * this colour space.
  * The colour spaces NSDeviceBlackColorSpace and NSCalibratedBlackColorSpace
- * are no longer supported by this class. They were not in the old OpenStep 
+ * are no longer supported by this class. They were not in the old OpenStep
  * specification, and are not used in the new Apple specification. The names are
  * used as synonyms to NSDeviceWhiteColorSpace and NSCalibratedWhiteColorSpace.
  */
 
+APPKIT_EXPORT_CLASS
 @interface NSColor : NSObject <NSCoding, NSCopying>
 {
 }
@@ -71,33 +94,33 @@ typedef enum _NSControlSize {
 //
 // Creating an NSColor from Component Values
 //
-+ (NSColor *)colorWithCalibratedHue:(float)hue
-			 saturation:(float)saturation
-			 brightness:(float)brightness
-			      alpha:(float)alpha;
-+ (NSColor *)colorWithCalibratedRed:(float)red
-			      green:(float)green
-			       blue:(float)blue
-			      alpha:(float)alpha;
-+ (NSColor *)colorWithCalibratedWhite:(float)white
-				alpha:(float)alpha;
++ (NSColor *)colorWithCalibratedHue:(CGFloat)hue
+			 saturation:(CGFloat)saturation
+			 brightness:(CGFloat)brightness
+			      alpha:(CGFloat)alpha;
++ (NSColor *)colorWithCalibratedRed:(CGFloat)red
+			      green:(CGFloat)green
+			       blue:(CGFloat)blue
+			      alpha:(CGFloat)alpha;
++ (NSColor *)colorWithCalibratedWhite:(CGFloat)white
+				alpha:(CGFloat)alpha;
 + (NSColor *)colorWithCatalogName:(NSString *)listName
 			colorName:(NSString *)colorName;
-+ (NSColor *)colorWithDeviceCyan:(float)cyan
-			 magenta:(float)magenta
-			  yellow:(float)yellow
-			   black:(float)black
-			   alpha:(float)alpha;
-+ (NSColor *)colorWithDeviceHue:(float)hue
-		     saturation:(float)saturation
-		     brightness:(float)brightness
-			  alpha:(float)alpha;
-+ (NSColor *)colorWithDeviceRed:(float)red
-			  green:(float)green
-			   blue:(float)blue
-			  alpha:(float)alpha;
-+ (NSColor *)colorWithDeviceWhite:(float)white
-			    alpha:(float)alpha;
++ (NSColor *)colorWithDeviceCyan:(CGFloat)cyan
+			 magenta:(CGFloat)magenta
+			  yellow:(CGFloat)yellow
+			   black:(CGFloat)black
+			   alpha:(CGFloat)alpha;
++ (NSColor *)colorWithDeviceHue:(CGFloat)hue
+		     saturation:(CGFloat)saturation
+		     brightness:(CGFloat)brightness
+			  alpha:(CGFloat)alpha;
++ (NSColor *)colorWithDeviceRed:(CGFloat)red
+			  green:(CGFloat)green
+			   blue:(CGFloat)blue
+			  alpha:(CGFloat)alpha;
++ (NSColor *)colorWithDeviceWhite:(CGFloat)white
+			    alpha:(CGFloat)alpha;
 
 //
 // Creating an NSColor With Preset Components
@@ -127,41 +150,41 @@ typedef enum _NSControlSize {
 //
 // Retrieving a Set of Components
 //
-- (void)getCyan:(float *)cyan
-	magenta:(float *)magenta
-	 yellow:(float *)yellow
-	  black:(float *)black
-	  alpha:(float *)alpha;	
-- (void)getHue:(float *)hue
-    saturation:(float *)saturation
-    brightness:(float *)brightness
-	 alpha:(float *)alpha;
-- (void)getRed:(float *)red
-	 green:(float *)green
-	  blue:(float *)blue
-	 alpha:(float *)alpha;
-- (void)getWhite:(float *)white
-	   alpha:(float *)alpha;
+- (void)getCyan:(CGFloat *)cyan
+	magenta:(CGFloat *)magenta
+	 yellow:(CGFloat *)yellow
+	  black:(CGFloat *)black
+	  alpha:(CGFloat *)alpha;
+- (void)getHue:(CGFloat *)hue
+    saturation:(CGFloat *)saturation
+    brightness:(CGFloat *)brightness
+	 alpha:(CGFloat *)alpha;
+- (void)getRed:(CGFloat *)red
+	 green:(CGFloat *)green
+	  blue:(CGFloat *)blue
+	 alpha:(CGFloat *)alpha;
+- (void)getWhite:(CGFloat *)white
+	   alpha:(CGFloat *)alpha;
 
 //
 // Retrieving Individual Components
 //
-- (float)alphaComponent;
-- (float)blackComponent;
-- (float)blueComponent;
-- (float)brightnessComponent;
+- (CGFloat)alphaComponent;
+- (CGFloat)blackComponent;
+- (CGFloat)blueComponent;
+- (CGFloat)brightnessComponent;
 - (NSString *)catalogNameComponent;
 - (NSString *)colorNameComponent;
-- (float)cyanComponent;
-- (float)greenComponent;
-- (float)hueComponent;
+- (CGFloat)cyanComponent;
+- (CGFloat)greenComponent;
+- (CGFloat)hueComponent;
 - (NSString *)localizedCatalogNameComponent;
 - (NSString *)localizedColorNameComponent;
-- (float)magentaComponent;
-- (float)redComponent;
-- (float)saturationComponent;
-- (float)whiteComponent;
-- (float)yellowComponent;
+- (CGFloat)magentaComponent;
+- (CGFloat)redComponent;
+- (CGFloat)saturationComponent;
+- (CGFloat)whiteComponent;
+- (CGFloat)yellowComponent;
 
 //
 // Converting to Another Color Space
@@ -173,20 +196,20 @@ typedef enum _NSControlSize {
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
 // + (NSColor *)colorWithCIColor:(CIColor *)color;
 + (NSColor *)colorWithColorSpace:(NSColorSpace *)space
-					   components:(const float *)comp
-							count:(int)number;
+                      components:(const CGFloat *)comp
+                           count:(NSInteger)number;
 - (NSColorSpace *)colorSpace;
 - (NSColor *)colorUsingColorSpace:(NSColorSpace *)space;
-- (void)getComponents:(float *)components;
-- (int)numberOfComponents;
+- (void)getComponents:(CGFloat *)components;
+- (NSInteger)numberOfComponents;
 #endif
 
 //
 // Changing the Color
 //
-- (NSColor *)blendedColorWithFraction:(float)fraction
+- (NSColor *)blendedColorWithFraction:(CGFloat)fraction
 			      ofColor:(NSColor *)aColor;
-- (NSColor *)colorWithAlphaComponent:(float)alpha;
+- (NSColor *)colorWithAlphaComponent:(CGFloat)alpha;
 
 //
 // Copying and Pasting
@@ -208,8 +231,8 @@ typedef enum _NSControlSize {
 //
 // Changing the color
 //
-- (NSColor*) highlightWithLevel: (float)level;
-- (NSColor*) shadowWithLevel: (float)level;
+- (NSColor*) highlightWithLevel: (CGFloat)level;
+- (NSColor*) shadowWithLevel: (CGFloat)level;
 
 + (NSColor*)colorWithPatternImage:(NSImage*)image;
 + (NSColor*)colorForControlTint:(NSControlTint)controlTint;
@@ -254,6 +277,12 @@ typedef enum _NSControlSize {
 + (NSColor*) windowBackgroundColor;
 + (NSColor*) windowFrameColor;
 + (NSColor*) windowFrameTextColor;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
++ (NSColor*) labelColor;
++ (NSColor*) secondaryLabelColor;
++ (NSColor*) tertiaryLabelColor;
++ (NSColor*) quaternaryLabelColor;
+#endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 + (NSArray*) controlAlternatingRowBackgroundColors;
@@ -261,6 +290,71 @@ typedef enum _NSControlSize {
 
 // Pattern colour
 - (NSImage*) patternImage;
+
+// Tooltip colours
++ (NSColor*) toolTipColor;
++ (NSColor*) toolTipTextColor;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
++ (NSColor *)colorWithSRGBRed:(CGFloat)red
+                        green:(CGFloat)green
+                         blue:(CGFloat)blue
+                        alpha:(CGFloat)alpha;
++ (NSColor *)colorWithGenericGamma22White:(CGFloat)white
+                                    alpha:(CGFloat)alpha;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9, GS_API_LATEST)
++ (NSColor *)colorWithRed:(CGFloat)red
+                    green:(CGFloat)green
+                     blue:(CGFloat)blue
+                    alpha:(CGFloat)alpha;
++ (NSColor *)colorWithHue:(CGFloat)hue
+               saturation:(CGFloat)saturation
+               brightness:(CGFloat)brightness
+                    alpha:(CGFloat)alpha;
++ (NSColor *)colorWithWhite:(CGFloat)white
+                      alpha:(CGFloat)alpha;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
++ (NSColor *)systemBlueColor;
++ (NSColor *)systemBrownColor;
++ (NSColor *)systemGrayColor;
++ (NSColor *)systemGreenColor;
++ (NSColor *)systemOrangeColor;
++ (NSColor *)systemPinkColor;
++ (NSColor *)systemPurpleColor;
++ (NSColor *)systemRedColor;
++ (NSColor *)systemYellowColor;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_12, GS_API_LATEST)
++ (NSColor *)colorWithDisplayP3Red:(CGFloat)red
+                             green:(CGFloat)green
+                              blue:(CGFloat)blue
+                             alpha:(CGFloat)alpha;
++ (NSColor *)colorWithColorSpace:(NSColorSpace *)space
+                             hue:(CGFloat)hue
+                      saturation:(CGFloat)saturation
+                      brightness:(CGFloat)brightness
+                           alpha:(CGFloat)alpha;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_13, GS_API_LATEST)
+- (NSColor *)colorUsingType:(NSColorType)type;
+- (NSColorType)type;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_14, GS_API_LATEST)
+- (NSColor *)colorWithSystemEffect:(NSColorSystemEffect)systemEffect;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_15, GS_API_LATEST)
++ (NSColor *)systemIndigoColor;
++ (NSColor *)systemTealColor;
+#endif
+
 #endif
 
 @end
@@ -278,5 +372,11 @@ APPKIT_EXPORT NSString	*NSSystemColorsDidChangeNotification;
 @end
 #endif
 
-#endif // _GNUstep_H_NSColor
+typedef struct CGColor *CGColorRef;
+@interface NSColor (GSQuartz)
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (CGColorRef)CGColor;
+#endif
+@end
 
+#endif // _GNUstep_H_NSColor
