@@ -29,22 +29,22 @@
 
 #ifndef _GNUstep_H_NSColorPanel
 #define _GNUstep_H_NSColorPanel
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <AppKit/NSApplication.h>
-#include <AppKit/NSBox.h>
-#include <AppKit/NSButton.h>
-#include <AppKit/NSColorPicking.h>
-#include <AppKit/NSColorWell.h>
-#include <AppKit/NSMatrix.h>
-#include <AppKit/NSNibDeclarations.h>
-#include <AppKit/NSPanel.h>
-#include <AppKit/NSSlider.h>
-#include <AppKit/NSSplitView.h>
+#import <AppKit/NSApplication.h>
+#import <AppKit/NSColorPicking.h>
+#import <AppKit/NSColorWell.h>
+#import <AppKit/NSNibDeclarations.h>
+#import <AppKit/NSPanel.h>
 
-@class NSView;
+@class NSBox;
+@class NSButton;
 @class NSColorList;
 @class NSEvent;
+@class NSMatrix;
+@class NSSlider;
+@class NSSplitView;
+@class NSView;
 
 enum {
   NSGrayModeColorPanel,
@@ -73,6 +73,7 @@ enum {
 - (void) orderFrontColorPanel: (id)sender;
 @end
 
+APPKIT_EXPORT_CLASS
 @interface NSColorPanel : NSPanel
 {
   // Attributes
@@ -131,12 +132,12 @@ enum {
 	 fromView:(NSView *)sourceView;
 - (void)setColor:(NSColor *)aColor;
 
-- (float)alpha;
+- (CGFloat)alpha;
 - (NSColor *)color;
 
 @end
 
 /* Notifications */
-APPKIT_EXPORT NSString *NSColorPanelColorChangedNotification;
+APPKIT_EXPORT NSString *NSColorPanelColorDidChangeNotification;
 
 #endif // _GNUstep_H_NSColorPanel
