@@ -30,13 +30,12 @@
 
 #ifndef _GNUstep_H_NSFont
 #define _GNUstep_H_NSFont
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSGeometry.h>
-#include <AppKit/AppKitDefines.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
 // For NSControlSize
-#include <AppKit/NSColor.h>
+#import <AppKit/NSColor.h>
 
 @class NSAffineTransform;
 @class NSCharacterSet;
@@ -75,13 +74,14 @@ typedef enum _NSFontRenderingMode
 } NSFontRenderingMode;
 #endif
 
-APPKIT_EXPORT const float *NSFontIdentityMatrix;
+APPKIT_EXPORT const CGFloat NSFontIdentityMatrix[6];
 
+APPKIT_EXPORT_CLASS
 @interface NSFont : NSObject <NSCoding, NSCopying>
 {
   NSString *fontName;
-  float matrix[6];
-  BOOL matrixExplicitlySet;
+  CGFloat matrix[6];
+  BOOL matrixExplicitlySet; // unused
   BOOL screenFont;
 
   id fontInfo;
@@ -113,29 +113,32 @@ APPKIT_EXPORT const float *NSFontIdentityMatrix;
 //
 // Creating a Font Object
 //
-+ (NSFont*) boldSystemFontOfSize: (float)fontSize;
++ (NSFont*) boldSystemFontOfSize: (CGFloat)fontSize;
 + (NSFont*) fontWithName: (NSString*)aFontName 
-		  matrix: (const float*)fontMatrix;
+		  matrix: (const CGFloat*)fontMatrix;
 + (NSFont*) fontWithName: (NSString*)aFontName
-		    size: (float)fontSize;
-+ (NSFont*) systemFontOfSize: (float)fontSize;
-+ (NSFont*) userFixedPitchFontOfSize: (float)fontSize;
-+ (NSFont*) userFontOfSize: (float)fontSize;
+		    size: (CGFloat)fontSize;
++ (NSFont*) systemFontOfSize: (CGFloat)fontSize;
++ (NSFont*) userFixedPitchFontOfSize: (CGFloat)fontSize;
++ (NSFont*) userFontOfSize: (CGFloat)fontSize;
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-+ (NSFont*) titleBarFontOfSize: (float)fontSize;
-+ (NSFont*) menuFontOfSize: (float)fontSize;
-+ (NSFont*) messageFontOfSize: (float)fontSize;
-+ (NSFont*) paletteFontOfSize: (float)fontSize;
-+ (NSFont*) toolTipsFontOfSize: (float)fontSize;
-+ (NSFont*) controlContentFontOfSize: (float)fontSize;
-+ (NSFont*) labelFontOfSize: (float)fontSize;
-+ (NSFont*) menuBarFontOfSize: (float)fontSize;
++ (NSFont*) titleBarFontOfSize: (CGFloat)fontSize;
++ (NSFont*) menuFontOfSize: (CGFloat)fontSize;
++ (NSFont*) messageFontOfSize: (CGFloat)fontSize;
++ (NSFont*) paletteFontOfSize: (CGFloat)fontSize;
++ (NSFont*) toolTipsFontOfSize: (CGFloat)fontSize;
++ (NSFont*) controlContentFontOfSize: (CGFloat)fontSize;
++ (NSFont*) labelFontOfSize: (CGFloat)fontSize;
++ (NSFont*) menuBarFontOfSize: (CGFloat)fontSize;
 #endif
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
-+ (NSFont*) fontWithDescriptor: (NSFontDescriptor*)descriptor size: (float)size;
++ (NSFont*) fontWithDescriptor: (NSFontDescriptor*)descriptor size: (CGFloat)size;
 + (NSFont*) fontWithDescriptor: (NSFontDescriptor*)descriptor 
-                          size: (float)size
+                 textTransform: (NSAffineTransform*)transform;
+// This method was a mistake in the 10.4 documentation
++ (NSFont*) fontWithDescriptor: (NSFontDescriptor*)descriptor 
+                          size: (CGFloat)size
                  textTransform: (NSAffineTransform*)transform;
 #endif
 
@@ -143,10 +146,10 @@ APPKIT_EXPORT const float *NSFontIdentityMatrix;
 // Font Sizes
 //
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-+ (float) labelFontSize;
-+ (float) smallSystemFontSize;
-+ (float) systemFontSize;
-+ (float) systemFontSizeForControlSize: (NSControlSize)controlSize;
++ (CGFloat) labelFontSize;
++ (CGFloat) smallSystemFontSize;
++ (CGFloat) systemFontSize;
++ (CGFloat) systemFontSizeForControlSize: (NSControlSize)controlSize;
 #endif
 
 //
@@ -179,24 +182,28 @@ APPKIT_EXPORT const float *NSFontIdentityMatrix;
 - (NSString*) encodingScheme;
 - (BOOL) isFixedPitch;
 - (BOOL) isBaseFont;
-- (const float*) matrix;
-- (float) pointSize;
+- (const CGFloat*) matrix;
+- (CGFloat) pointSize;
 - (NSFont*) printerFont;
 - (NSFont*) screenFont;
-- (float) ascender;
-- (float) descender;
-- (float) capHeight;
-- (float) italicAngle;
+- (CGFloat) ascender;
+- (CGFloat) descender;
+- (CGFloat) capHeight;
+- (CGFloat) italicAngle;
 - (NSSize) maximumAdvancement;
 - (NSSize) minimumAdvancement;
-- (float) underlinePosition;
-- (float) underlineThickness;
-- (float) xHeight;
-- (float) widthOfString: (NSString*)string;
-- (float) defaultLineHeightForFont;
+- (CGFloat) underlinePosition;
+- (CGFloat) underlineThickness;
+- (CGFloat) xHeight;
+- (CGFloat) widthOfString: (NSString*)string;
+- (CGFloat) defaultLineHeightForFont;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (CGFloat) leading;
+
+#endif
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-- (unsigned) numberOfGlyphs;
+- (NSUInteger) numberOfGlyphs;
 - (NSCharacterSet*) coveredCharacterSet;
 #endif
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
@@ -233,6 +240,17 @@ APPKIT_EXPORT const float *NSFontIdentityMatrix;
 - (int) positionsForCompositeSequence: (NSGlyph*)glyphs 
                        numberOfGlyphs: (int)numGlyphs 
                            pointArray: (NSPoint*)points;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (void) getAdvancements: (NSSizeArray)advancements
+               forGlyphs: (const NSGlyph*)glyphs
+                   count: (NSUInteger)count;
+- (void) getAdvancements: (NSSizeArray)advancements
+         forPackedGlyphs: (const void*)glyphs
+                   count: (NSUInteger)count;
+- (void) getBoundingRects: (NSRectArray)bounds
+                forGlyphs: (const NSGlyph*)glyphs
+                    count: (NSUInteger)count;
+#endif
 
 - (NSStringEncoding) mostCompatibleStringEncoding;
 
@@ -270,4 +288,17 @@ APPKIT_EXPORT NSString *NSAFMVersion;
 APPKIT_EXPORT NSString *NSAFMWeight;
 APPKIT_EXPORT NSString *NSAFMXHeight;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_11, GS_API_LATEST)
+typedef CGFloat NSFontWeight;
+APPKIT_EXPORT const CGFloat NSFontWeightUltraLight;
+APPKIT_EXPORT const CGFloat NSFontWeightThin;
+APPKIT_EXPORT const CGFloat NSFontWeightLight;
+APPKIT_EXPORT const CGFloat NSFontWeightRegular;
+APPKIT_EXPORT const CGFloat NSFontWeightMedium;
+APPKIT_EXPORT const CGFloat NSFontWeightSemibold;
+APPKIT_EXPORT const CGFloat NSFontWeightBold;
+APPKIT_EXPORT const CGFloat NSFontWeightHeavy;
+APPKIT_EXPORT const CGFloat NSFontWeightBlack;
+#endif
+
 #endif // _GNUstep_H_NSFont
