@@ -107,19 +107,26 @@ APPKIT_EXPORT id NSNotApplicableMarker;
 APPKIT_EXPORT NSString *NSAlignmentBinding;
 APPKIT_EXPORT NSString *NSContentArrayBinding;
 APPKIT_EXPORT NSString *NSContentBinding;
+APPKIT_EXPORT NSString *NSContentDictionaryBinding;
 APPKIT_EXPORT NSString *NSContentObjectBinding;
 APPKIT_EXPORT NSString *NSContentValuesBinding;
 APPKIT_EXPORT NSString *NSEditableBinding;
 APPKIT_EXPORT NSString *NSEnabledBinding;
+APPKIT_EXPORT NSString *NSExcludedKeysBinding;
 APPKIT_EXPORT NSString *NSFontBinding;
 APPKIT_EXPORT NSString *NSFontNameBinding;
 APPKIT_EXPORT NSString *NSFontSizeBinding;
 APPKIT_EXPORT NSString *NSHiddenBinding;
+APPKIT_EXPORT NSString *NSIncludedKeysBinding;
+APPKIT_EXPORT NSString *NSInitialKeyBinding;
+APPKIT_EXPORT NSString *NSInitialValueBinding;
+APPKIT_EXPORT NSString *NSLocalizedKeyDictionaryBinding;
 APPKIT_EXPORT NSString *NSSelectedIndexBinding;
 APPKIT_EXPORT NSString *NSSelectedObjectBinding;
 APPKIT_EXPORT NSString *NSSelectedTagBinding;
 APPKIT_EXPORT NSString *NSSelectedValueBinding;
 APPKIT_EXPORT NSString *NSSelectionIndexesBinding;
+APPKIT_EXPORT NSString *NSSelectionIndexPathsBinding;
 APPKIT_EXPORT NSString *NSSortDescriptorsBinding;
 APPKIT_EXPORT NSString *NSTextColorBinding;
 APPKIT_EXPORT NSString *NSTitleBinding;
