@@ -29,8 +29,15 @@
 #import <Foundation/NSGeometry.h>
 #import <Foundation/NSKeyedArchiver.h>
 #import <AppKit/NSLayoutAnchor.h>
+#import <AppKit/NSWindow.h>
 
-@class NSControl, NSView, NSAnimation, NSArray, NSMutableArray, NSDictionary;
+@class NSControl, NSAnimation, NSArray, NSMutableArray, NSDictionary, NSView;
+
+typedef float NSLayoutPriority;
+typedef struct GSIntrinsicContentSizePriority {
+  NSLayoutPriority horizontal;
+  NSLayoutPriority vertical;
+} GSIntrinsicContentSizePriority;
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
 
@@ -39,7 +46,6 @@ extern "C" {
 #endif
 
 // Priority
-typedef float NSLayoutPriority;
 static const NSLayoutPriority NSLayoutPriorityRequired = 1000.0;
 static const NSLayoutPriority NSLayoutPriorityDefaultHigh = 750.0;
 static const NSLayoutPriority NSLayoutPriorityDragThatCanResizeWindow = 510.0;
@@ -166,6 +172,14 @@ APPKIT_EXPORT_CLASS
 
 @end
 
+@interface NSWindow (NSConstraintBasedLayoutCoreMethods)
+
+- (void) _bootstrapAutoLayout;
+
+- (void) layoutIfNeeded;
+
+@end
+
 #if	defined(__cplusplus)
 }
 #endif
