@@ -36,6 +36,7 @@
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
 
+APPKIT_EXPORT_CLASS
 @interface NSLevelIndicator : NSControl
 {
 }
@@ -49,14 +50,14 @@
 - (double) criticalValue;
 - (void) setCriticalValue: (double) val;
 
-- (int) numberOfMajorTickMarks;
-- (int) numberOfTickMarks;
-- (NSRect) rectOfTickMarkAtIndex: (int)index;
-- (void) setNumberOfMajorTickMarks: (int)count;
-- (void) setNumberOfTickMarks: (int)count;
+- (NSInteger) numberOfMajorTickMarks;
+- (NSInteger) numberOfTickMarks;
+- (NSRect) rectOfTickMarkAtIndex: (NSInteger)index;
+- (void) setNumberOfMajorTickMarks: (NSInteger)count;
+- (void) setNumberOfTickMarks: (NSInteger)count;
 - (void) setTickMarkPosition: (NSTickMarkPosition)pos;
 - (NSTickMarkPosition) tickMarkPosition;
-- (double) tickMarkValueAtIndex: (int)index;
+- (double) tickMarkValueAtIndex: (NSInteger)index;
 
 @end
 
