@@ -32,9 +32,10 @@
 
 #ifndef _GNUstep_H_NSMenuItem
 #define _GNUstep_H_NSMenuItem
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <Foundation/NSObject.h>
+#import <Foundation/NSObject.h>
+#import <AppKit/NSUserInterfaceValidation.h>
 
 @class NSAttributedString;
 @class NSString;
@@ -47,7 +48,7 @@
  * placed in a menu as a menu item.  The [NSMenuItem] class provides
  * a reference implementation suitable for most uses.
  */
-@protocol NSMenuItem <NSCopying, NSCoding, NSObject>
+@protocol NSMenuItem <NSValidatedUserInterfaceItem, NSCopying, NSCoding, NSObject>
 
 /**
    <p> Returns a seperator.   This is just a blank menu item which serves 
@@ -106,7 +107,7 @@
    Returns the indentation level, a number between 0 and 15.
    </p>
  */
-- (int)indentationLevel;
+- (NSInteger)indentationLevel;
 #endif
 
 /**
@@ -151,7 +152,7 @@
    Returns the key equivalent mask.
    </p>
  */
-- (unsigned int) keyEquivalentModifierMask;
+- (NSUInteger) keyEquivalentModifierMask;
 
 /**
    <p>
@@ -167,7 +168,7 @@
  */
 - (NSImage*) mixedStateImage;
 - (NSString*) mnemonic;
-- (unsigned) mnemonicLocation;
+- (NSUInteger) mnemonicLocation;
 
 /**
    <p>
@@ -218,7 +219,7 @@
 - (void) setImage: (NSImage*)menuImage;
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
-- (void)setIndentationLevel: (int)level;
+- (void)setIndentationLevel: (NSInteger)level;
 #endif
 
 /**
@@ -234,7 +235,7 @@
    key equivalent requires ALT, Control or other key modifiers.
    </p>
  */
-- (void) setKeyEquivalentModifierMask: (unsigned int)mask;
+- (void) setKeyEquivalentModifierMask: (NSUInteger)mask;
 
 /**
    <p> Sets the menu which this item belongs to.   This method does not retain the
@@ -249,7 +250,7 @@
    </p>
  */
 - (void) setMixedStateImage: (NSImage*)image;
-- (void) setMnemonicLocation: (unsigned) location;
+- (void) setMnemonicLocation: (NSUInteger) location;
 
 /**
    <p>
@@ -277,7 +278,7 @@
    Sets the state of the the receiver.
    </p>
  */
-- (void) setState: (int)state;
+- (void) setState: (NSInteger)state;
 
 /**
    <p>
@@ -292,7 +293,7 @@
    Sets the tag of the reciever as <var>anInt</var>.
    </p>
  */
-- (void) setTag: (int)anInt;
+- (void) setTag: (NSInteger)anInt;
 
 /**
    <p>
@@ -318,7 +319,7 @@
    Returns the state of the receiver.
    </p>
  */
-- (int) state;
+- (NSInteger) state;
 /**
    <p>
    Returns the attached submenu.
@@ -331,7 +332,7 @@
    Returns the tag of the receiver.
    </p>
  */
-- (int) tag;
+- (NSInteger) tag;
 
 /**
    <p>
@@ -356,7 +357,7 @@
    Returns the user defined key equivalent modifier.
    </p>
  */
-- (unsigned int) userKeyEquivalentModifierMask;
+- (NSUInteger) userKeyEquivalentModifierMask;
 
 /**
    <p>
@@ -367,21 +368,22 @@
 
 @end
 
-@interface NSMenuItem : NSObject <NSMenuItem>
+APPKIT_EXPORT_CLASS
+@interface NSMenuItem : NSObject <NSMenuItem, NSValidatedUserInterfaceItem>
 {
   NSMenu *_menu;
   NSString *_title;
   NSString *_keyEquivalent;
-  unsigned int _keyEquivalentModifierMask;
-  unsigned _mnemonicLocation;
-  int _state;
+  NSUInteger _keyEquivalentModifierMask;
+  NSUInteger _mnemonicLocation;
+  NSInteger _state;
   NSImage *_image;
   NSImage *_onStateImage;
   NSImage *_offStateImage;
   NSImage *_mixedStateImage;
   id _target;
   SEL _action;
-  int _tag;
+  NSInteger _tag;
   id _representedObject;
   NSMenu *_submenu;
   BOOL _enabled;
