@@ -25,18 +25,19 @@
 
 #ifndef _NSOpenGLView_h
 #define _NSOpenGLView_h
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <AppKit/NSView.h>
+#import <AppKit/NSView.h>
 
 @class NSOpenGLContext;
 @class NSOpenGLPixelFormat;
 
+APPKIT_EXPORT_CLASS
 @interface NSOpenGLView : NSView
 {
   NSOpenGLContext 	*glcontext;
   NSOpenGLPixelFormat	*pixel_format;
-  BOOL			attached;
+  BOOL			prepared;
 }
 
 + (NSOpenGLPixelFormat*) defaultPixelFormat;
