@@ -9,7 +9,7 @@
    Date: 1996
 
    Fixes and updates made by
-   Author: Gregory John Casamento <borgheron@yahoo.com>
+   Author: Gregory John Casamento <greg.casamento@gmail.com>
    Date: 2000
    
    This file is part of the GNUstep GUI Library.
@@ -33,21 +33,23 @@
 
 #ifndef _GNUstep_H_NSScreen
 #define _GNUstep_H_NSScreen
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <Foundation/NSObject.h>
-#include <AppKit/NSGraphics.h>
+#import <Foundation/NSObject.h>
+#import <AppKit/NSGraphics.h>
 
 @class NSArray;
 @class NSDictionary;
 
+APPKIT_EXPORT_CLASS
 @interface NSScreen : NSObject
 {
 @private
   NSWindowDepth        _depth;
   NSRect               _frame;
   int                  _screenNumber;
-  NSWindowDepth       *_supportedWindowDepths;
+  NSWindowDepth		*_supportedWindowDepths;
+  void			*_reserved;
 }
 
 /*
@@ -56,7 +58,7 @@
 + (NSScreen*) mainScreen;
 + (NSScreen*) deepestScreen;
 + (NSArray*) screens;
-+ (void)resetScreens;
++ (void) resetScreens;
 
 /*
  * Reading Screen Information
@@ -73,7 +75,10 @@
 - (int) screenNumber;
 #endif
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
-- (float) userSpaceScaleFactor;
+- (CGFloat) userSpaceScaleFactor;
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+- (CGFloat) backingScaleFactor;
 #endif
 
 @end
