@@ -30,9 +30,10 @@
 
 #ifndef _GNUstep_H_NSScrollView
 #define _GNUstep_H_NSScrollView
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSView.h>
+#import <AppKit/NSScroller.h>
 
 enum
 {
@@ -49,6 +50,7 @@ typedef NSInteger NSScrollElasticity;
 @class NSCursor;
 @class NSScroller;
 
+APPKIT_EXPORT_CLASS
 @interface NSScrollView : NSView
 {
   NSClipView *_contentView;
@@ -75,6 +77,8 @@ typedef NSInteger NSScrollElasticity;
   BOOL _autohidesScrollers;
   NSScrollElasticity _horizScrollElasticity;
   NSScrollElasticity _vertScrollElasticity;
+  NSScrollerStyle _scrollerStyle;
+  NSScrollerKnobStyle _scrollerKnobStyle;
 }
 
 /* Calculating layout */
@@ -187,6 +191,19 @@ typedef NSInteger NSScrollElasticity;
 /* Arranging components */
 - (void)tile;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+/** The scroller style. By default, NSScrollerStyleDefault. */
+- (NSScrollerStyle)scrollerStyle;
+/** Sets the scroller style. In the default theme, this must be NSScrollerStyleDefault. */
+- (void)setScrollerStyle:(NSScrollerStyle)style;
+/** The scroller knob style. By default, NSScrollerStyleDefault. */
+- (NSScrollerKnobStyle)scrollerKnobStyle;
+/** Sets the scroller knob style. In the default theme, this must be NSScrollerKnobStyleDefault. */
+- (void)setScrollerKnobStyle:(NSScrollerKnobStyle)style;
+/** Shows the scrollers if they're overlay scrollers. */
+- (void)flashScrollers;
+#endif
+
 @end
 
 #endif /* _GNUstep_H_NSScrollView */
