@@ -30,15 +30,17 @@
 #ifndef _GNUstep_H_NSSecureTextField
 #define _GNUstep_H_NSSecureTextField
 
-#include <AppKit/NSTextField.h>
-#include <AppKit/NSTextFieldCell.h>
+#import <AppKit/NSTextField.h>
+#import <AppKit/NSTextFieldCell.h>
 
+APPKIT_EXPORT_CLASS
 @interface NSSecureTextField : NSTextField
 {}
 - (void) setEchosBullets:(BOOL)flag;
 - (BOOL) echosBullets;
 @end
 
+APPKIT_EXPORT_CLASS
 @interface NSSecureTextFieldCell : NSTextFieldCell
 {
   BOOL _echosBullets;
