@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,12 +27,23 @@
 
 #ifndef _GNUstep_H_NSTableHeaderCell
 #define _GNUstep_H_NSTableHeaderCell
+#import <AppKit/AppKitDefines.h>
 
-#include <AppKit/NSTextFieldCell.h>
+#import <AppKit/NSTextFieldCell.h>
 
+APPKIT_EXPORT_CLASS
 @interface NSTableHeaderCell : NSTextFieldCell
 {
 }
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (void)drawSortIndicatorWithFrame: (NSRect)cellFrame 
+                            inView: (NSView *)controlView
+                         ascending: (BOOL)ascending 
+                          priority: (int)priority;
+- (NSRect)sortIndicatorRectForBounds: (NSRect)theRect;
+#endif
+
 @end
 
 #endif
