@@ -30,7 +30,7 @@
 #ifndef _GNUstep_H_GSHbox
 #define _GNUstep_H_GSHbox
 
-#include "GSTable.h"
+#import "GSTable.h"
 
 /** 
   <unit>
@@ -169,6 +169,7 @@
 
   </unit>
 */
+APPKIT_EXPORT_CLASS
 @interface GSHbox: GSTable
 {
   BOOL _haveViews;
