@@ -30,8 +30,10 @@
 #ifndef _GNUstep_H_GSTrackingRect
 #define _GNUstep_H_GSTrackingRect
 
-#include <AppKit/NSView.h>
+#import <Foundation/NSObject.h>
+#import <AppKit/NSView.h>
 
+APPKIT_EXPORT_CLASS
 @interface GSTrackingRect : NSObject <NSCoding>
 {
 @public
@@ -64,12 +66,6 @@
 - (BOOL) isValid;
 - (void) invalidate;
 
-/*
- * NSCoding protocol
- */
-- (void) encodeWithCoder: (NSCoder*)aCoder;
-- (id) initWithCoder: (NSCoder*)aDecoder;
-
 @end
 
 #endif /* _GNUstep_H_GSTrackingRect */
